@@ -46,7 +46,7 @@ class IvyBloomAPIClient:
         # Build default headers including auth; prefer API key for stability, then JWT/OAuth
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.4.28",
+            "User-Agent": "ivybloom-cli/0.4.37",
             "Accept": "application/json"
         }
         # Add Authorization header via AuthManager (JWT/OAuth/API key)
@@ -362,8 +362,38 @@ class IvyBloomAPIClient:
         return self.get("/api/cli/jobs", params=params)
     
     def list_projects(self) -> List[Dict[str, Any]]:
-        """List user's projects"""
-        return self.get("/api/cli/projects")
+        """List user's projects with response normalization.
+        
+        Returns a list of project dicts. Accepts multiple response shapes:
+        - [ {..}, {..} ]
+        - { "projects": [..] }
+        - { "data": [..] }
+        Also maps legacy "project_id" -> "id" for compatibility.
+        """
+        data = self.get("/api/cli/projects")
+        items: List[Dict[str, Any]]
+        if isinstance(data, list):
+            raw_items = data
+        elif isinstance(data, dict):
+            if isinstance(data.get("projects"), list):
+                raw_items = data["projects"]
+            elif isinstance(data.get("data"), list):
+                raw_items = data["data"]
+            else:
+                raise Exception("Unexpected response while listing projects (expected a list of projects).")
+        else:
+            raise Exception("Unexpected response while listing projects (expected a list of projects).")
+
+        items = []
+        for item in raw_items:
+            if not isinstance(item, dict):
+                # Skip malformed entries rather than failing the entire call
+                continue
+            normalized = dict(item)
+            if "id" not in normalized and "project_id" in normalized:
+                normalized["id"] = normalized["project_id"]
+            items.append(normalized)
+        return items
     
     def get_project(self, project_id: str) -> Dict[str, Any]:
         """Get project details"""
