@@ -167,8 +167,21 @@ def list(ctx, format, interactive):
                             _execute_project_action(ctx, selected_project_id, action, selected_project_data)
     
     except Exception as e:
-        # Surface as CLI error (stderr, non-zero)
-        raise click.ClickException(f"Error listing projects: {e}")
+        # Provide actionable, user-friendly error messages
+        msg = str(e)
+        hints = []
+        if "Not authenticated" in msg or "Authentication" in msg or "401" in msg:
+            hints.append("Run 'ivybloom auth status' to verify login and API key")
+            hints.append("If needed, run 'ivybloom auth login --link' to relink this CLI")
+        if "Unexpected response" in msg:
+            hints.append("The server returned an unexpected format. Try again in a moment")
+            hints.append("Run with --debug for request/response details")
+        if "timeout" in msg.lower():
+            hints.append("Network timeout. Check your connection and try again")
+        if not hints:
+            hints.append("Re-run with '--debug' to see request/response diagnostics")
+        hint_text = "\n".join(f"   • {h}" for h in hints)
+        raise click.ClickException(f"Error listing projects: {msg}\n\nTroubleshooting:\n{hint_text}")
 
 @projects.command()
 @click.argument('project_id')
