@@ -30,11 +30,24 @@ class JobsService:
 
 	@staticmethod
 	def format_row(job: Dict[str, Any]) -> List[str]:
+		job_id = str(job.get("job_id") or job.get("id") or "")
+		# Truncate job ID to first 8 chars
+		if len(job_id) > 8:
+			job_id = job_id[:8]
+		
+		# Format completed_at or created_at
+		completed_at = str(job.get("completed_at") or "")
+		if not completed_at:
+			completed_at = str(job.get("created_at") or "")
+		# Truncate timestamp to just the date part if it's an ISO format
+		if len(completed_at) > 10 and "-" in completed_at:
+			completed_at = completed_at.split("T")[0]
+		
 		return [
-			str(job.get("job_id") or job.get("id") or ""),
+			job_id,
 			str(job.get("tool_name") or job.get("job_type") or ""),
 			str(job.get("status", "")),
-			str(job.get("result") or job.get("job_title") or job.get("title") or ""),
+			completed_at,
 		]
 
 
