@@ -38,13 +38,13 @@ class AuthManager:
             self._store_api_key_file(api_key)
     
     def get_api_key(self, username: str = "default") -> Optional[str]:
-        """Retrieve stored API key from env, secure storage, or file fallback.
+        """Retrieve stored API key from env, file fallback, or secure storage.
         
-        Order of precedence:
+        Updated order of precedence (to avoid stale keyring entries in TUI/subprocesses):
           1) OS env var IVYBLOOM_API_KEY
           2) OS env var IVY_API_KEY (legacy)
-          3) Secure storage via keyring
-          4) Local file fallback in config dir
+          3) Local file fallback in config dir
+          4) Secure storage via keyring
         """
         # 1) Environment variable overrides for easy persistence in CI/TUI subprocesses
         try:
@@ -55,7 +55,12 @@ class AuthManager:
         except Exception:
             pass
         
-        # 2) Secure storage via keyring
+        # 2) File fallback (preferred over keyring for cross-process consistency)
+        file_key = self._get_api_key_file()
+        if file_key:
+            return file_key
+        
+        # 3) Secure storage via keyring
         try:
             api_key = keyring.get_password(self.service_name, username)
             if api_key:
@@ -63,8 +68,7 @@ class AuthManager:
         except Exception:
             pass
         
-        # 3) Fallback to file storage
-        return self._get_api_key_file()
+        return None
     
     def remove_api_key(self, username: str = "default") -> None:
         """Remove stored API key and all authentication data"""
